==> nextcloud-28.0.9.tgz: nextcloud/apps/oauth2/l10n/cs.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Váš klient není autorizován pro připojení se. Informujte správce svého klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL adresu přesměrování je třeba uvádět celou, např. https://yourdomain.com/umisteni",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Umožní ověřování kompatibilní s OAuth2 z ostatních webových aplikací.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikace OAuth2 umožňuje správcům nastavit vestavěný postup ověřování tak, aby podporoval také OAuth2 kompatibilní ověřování z ostatních webových aplikací.",
    "OAuth 2.0 clients" : "OAuth 2.0 klienti",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 umožňuje externím službám vyžádat si přístup k {instanceName}.",
    "Name" : "Název",
    "Redirection URI" : "URL pro přesměrování",
    "Client Identifier" : "Identifikátor klienta",
    "Secret key" : "Tajný klíč",
    "Delete client" : "Smazat klienta",
    "Add client" : "Přidat klienta",
    "Add" : "Přidat",
    "Delete" : "Smazat",
    "Show client secret" : "Zobrazit klientské tajemství"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/oauth2/l10n/cs.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Váš klient není autorizován pro připojení se. Informujte správce svého klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL adresu přesměrování je třeba uvádět celou, např. https://yourdomain.com/umisteni",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Umožní ověřování kompatibilní s OAuth2 z ostatních webových aplikací.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikace OAuth2 umožňuje správcům nastavit vestavěný postup ověřování tak, aby podporoval také OAuth2 kompatibilní ověřování z ostatních webových aplikací.",
    "OAuth 2.0 clients" : "OAuth 2.0 klienti",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 umožňuje externím službám vyžádat si přístup k {instanceName}.",
    "Name" : "Název",
    "Redirection URI" : "URL pro přesměrování",
    "Client Identifier" : "Identifikátor klienta",
    "Secret key" : "Tajný klíč",
    "Delete client" : "Smazat klienta",
    "Make sure you store the secret key, it cannot be recovered." : "Nezapomeňte si uložit tajný klíč – není možné ho obnovit.",
    "Add client" : "Přidat klienta",
    "Add" : "Přidat",
    "Delete" : "Smazat",
    "Show client secret" : "Zobrazit klientské tajemství",
    "Hide client secret" : "Skrýt tajemství klienta"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
